use Test::More;
use strict;
use HTTP::Status qw(HTTP_NOT_FOUND HTTP_SERVICE_UNAVAILABLE);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Config qw( DatabaseConfig );
use DE_EPAGES::WebInterface::API::FakeRequest;
use DE_EPAGES::WebInterfacePoolDB::API::ASPoolDB qw( RunOnASPoolDB );

plan tests => 5;

sub Main {
    my $StoreName = 'REDIRECTTEST';
    my $Config = DatabaseConfig($StoreName);
    $Config->section( 'Connection', { 'redirect' => 'WebAdapterError.html' } );

    my $ServerName = 'localhost';
    my $URL = "http://$ServerName/epages/$StoreName.sf";

    my $FakeRequest = DE_EPAGES::WebInterface::API::FakeRequest->new();
    my $Response = $FakeRequest->get( $URL );

    cmp_ok( $Response->code, '==', HTTP_SERVICE_UNAVAILABLE, '503 Service unavailable' );
    cmp_ok( $Response->header('Retry-After'), '==', 120, 'Retry-After: 900' ); ## no critic qw(ProhibitMagicNumbers)
    like( $Response->content, qr/Heavy Traffic/, 'content' );

    # test for non-existing database
    $StoreName = 'UNKNOWN';
    $URL = "http://$ServerName/epages/$StoreName.sf";
    $Response = $FakeRequest->get( $URL );
    ok( !$Response->is_success, 'Unknown URL' );
    is( $Response->code, HTTP_NOT_FOUND, 'Unknown URL = 404' );
}

sub Init {
    Cleanup();
    RunOnASPoolDB( sub {
        my $ASPoolDB = shift;
        $ASPoolDB->insertSite('REDIRECTTEST', 'REDIRECTTEST-GUID', '/');
        $ASPoolDB->setSiteRequests('REDIRECTTEST', '/', [{
            'Host' => 'localhost',
            'URI' => '/epages/REDIRECTTEST.'
        }]);
    });
}

sub Cleanup {
    RunOnASPoolDB( sub {
        my $ASPoolDB = shift;
        $ASPoolDB->deleteSite('REDIRECTTEST-GUID');
    });
}

RunScript( Debug => 1, Sub=> sub {
    Init();
    Main();
    Cleanup();
});
