use Test::More;
use Time::HiRes qw( time );
use strict;
use DE_EPAGES::Core::API::EpagesConfig qw( EpagesConfig );
use DE_EPAGES::Core::API::IDN qw( EncodeDomain );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::WebInterface::API::FakeRequest;

plan tests => 10;

sub Main {

    my $HostName = EncodeDomain( EpagesConfig()->get('DE_EPAGES::Object', 'SystemDomainName', 'localhost') );
    my $URL = "http://$HostName/epages/TestRequest.sf";
    my $FakeRequest = DE_EPAGES::WebInterface::API::FakeRequest->new;
    my $Response = $FakeRequest->get( $URL."?PerformanceBar=1" );

    cmp_ok( $Response->code, '==', 200, '200 OK' );
    cmp_ok( $Response->content, 'eq', 'TestRequest: OK', 'content' );
    my @cookie = split(/, /  ,$Response->header('Set-Cookie'));
    my %cookieValues;
    foreach my $setCookie (@cookie)
    {
        if($setCookie=~/^(.*?)=(.*?);/){
            $cookieValues{$1} = $2;
        }
    }

    ok($cookieValues{'PerformanceBar'} eq 'enabled' ,'PerformanceBar is enabled');

    SKIP: {
        skip( 'Forced skip of timing tests.', 1 ) if $ENV{'SKIP_TIMING'};
        cmp_ok($cookieValues{'RequestTime'},'<',0.009,'RequestTime is set and smaller then 0.009');
    }

    ok(defined($cookieValues{'TLETime'}),'TLE Value is set');
    ok(defined($cookieValues{'MysqlTime'}),'Mysql Value is set');
    cmp_ok($cookieValues{'AppServerMemory'},'>',0,'Application Server Memory Usage is set and bigger then 0');

    $Response = $FakeRequest->get( $URL."?PerformanceBar=0" );

    @cookie = split(/, /  ,$Response->header('Set-Cookie'));
    %cookieValues = ();
    foreach my $setCookie (@cookie) {
        if($setCookie=~/^(.*?)=(.*?);/){
            $cookieValues{$1} = $2;
        }
    }

    is($cookieValues{'PerformanceBar'}, '', 'PerformanceBar cookie is deleted');
    ok(!defined($cookieValues{'TLETime'}),'TLE Value is not set');
    ok(!defined($cookieValues{'MysqlTime'}),'Mysql Value is not set');

    return;
}

RunScript(Sub=>\&Main, Debug=>1);
