use Test::More;
use Time::HiRes qw( time );
use strict;
use DE_EPAGES::Core::API::EpagesConfig qw( EpagesConfig );
use DE_EPAGES::Core::API::IDN qw( EncodeDomain );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::WebInterface::API::FakeRequest;

plan tests => 3;

sub Main {

    my $HostName = EncodeDomain( EpagesConfig()->get('DE_EPAGES::Object', 'SystemDomainName', 'localhost') );
    my $URL = "http://$HostName/epages/TestRequest.sf";
    my $FakeRequest = DE_EPAGES::WebInterface::API::FakeRequest->new;
    my $Response = $FakeRequest->get( $URL );

    cmp_ok( $Response->code, '==', 200, '200 OK' );
    cmp_ok( $Response->content, 'eq', 'TestRequest: OK', 'content' );

    SKIP: {
        skip( 'Forced skip of timing tests.', 1 ) if $ENV{'SKIP_TIMING'};
        my $time0 = time();
        $FakeRequest->get( $URL ) for 1..1000;
        my $diff = sprintf '%0.3f', time() - $time0;
        cmp_ok( time()-$time0, '<', 1, "1000 tests requests per second (1000 request took $diff s)" );
    }
    return;
}

RunScript(Sub=>\&Main, Debug=>1);
