use strict;
use Test::More;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::WebInterface::API::Object::WebAdapter;

plan tests => 5;

sub Main {

    my @Headers : shared = (
        'GET dummy',
        'user-agent: epages',
        'x-epages-CONTENT_TYPE: text/plain',
        'x-epages-HTTP_FRONT_END_HTTPS: on',
    );
    my $WA = MyFakeWebAdapter->new( \@Headers, '' );
    my ($Request, $hWebServerVars) = $WA->receive;

    is( $Request->content_type, 'text/plain', 'Request header: Content-Type' );
    is( $hWebServerVars->{CONTENT_TYPE}, 'text/plain', 'Server variable: CONTENT_TYPE' );
    ok( $hWebServerVars->{SERVER_PORT_SECURE}, 'Front-End_Https: on' );

    $Headers[2] = 'x-epages-HTTP_X_FORWARDED_PROTO: https';
    $WA = MyFakeWebAdapter->new( \@Headers, '' );
    ($Request, $hWebServerVars) = $WA->receive;
    ok( $hWebServerVars->{SERVER_PORT_SECURE}, 'X-Forwarded-Proto: https' );

    $Headers[2] = 'x-epages-HTTP_X_FORWARDED_PROTO: http';
    $WA = MyFakeWebAdapter->new( \@Headers, '' );
    ($Request, $hWebServerVars) = $WA->receive;
    ok( !$hWebServerVars->{SERVER_PORT_SECURE}, 'X-Forwarded-Proto: http' );

    return;
}

RunScript(Sub=>\&Main, Debug=>1);

#==============================================================================
# package      MyFakeWebAdapter
# state        private
#==============================================================================
package MyFakeWebAdapter;
use base qw( DE_EPAGES::WebInterface::API::Object::WebAdapter );

sub new {
    my $class = shift;
    my ($aHeader, $Content) = @_;

    my $self = $class->SUPER::new;
    $self->{Header} = $aHeader;
    $self->{Content} = $Content;
    return $self;
}

sub _sysread { ## no critic qw(ProhibitUnusedPrivateSubroutines)
    my $self = shift;

    return $self->{'Header'}, \$self->{'Content'};
}
